@@ -3,7 +3,7 @@
  * @ingroup MAT
  */
 /*
- * Copyright (c) 2005-2018, Christopher C. Hulbert
+ * Copyright (c) 2005-2019, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,7 @@
  */
 
 /* FIXME: Implement Unicode support */
+#include "safe-math.h"
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -38,7 +39,7 @@
 #   define __STDC_FORMAT_MACROS
 #   include <inttypes.h>
 #endif
-#if defined(_WIN64) || defined(_WIN32)
+#if (defined(_WIN64) || defined(_WIN32)) && !defined(__CYGWIN__)
 #   include <io.h>
 #   define mktemp _mktemp
 #endif
@@ -67,13 +68,13 @@ ReadData(mat_t *mat, matvar_t *matvar)
     if ( mat == NULL || matvar == NULL || mat->fp == NULL )
         return;
     else if ( mat->version == MAT_FT_MAT5 )
-        Read5(mat,matvar);
+        Mat_VarRead5(mat,matvar);
 #if defined(MAT73) && MAT73
     else if ( mat->version == MAT_FT_MAT73 )
         Mat_VarRead73(mat,matvar);
 #endif
     else if ( mat->version == MAT_FT_MAT4 )
-        Read4(mat,matvar);
+        Mat_VarRead4(mat,matvar);
     return;
 }
 
@@ -198,6 +199,63 @@ ClassType2DataType(enum matio_classes class_type)
     }
 }
 
+/** @brief Gets number of elements from a variable
+ *
+ * Gets number of elements from a variable by overflow-safe
+ * multiplication
+ * @ingroup MAT
+ * @param matvar MAT variable information
+ * @param nelems Number of elements
+ * @retval 0 on success
+ */
+int SafeMulDims(const matvar_t *matvar, size_t* nelems)
+{
+    int i;
+
+    for ( i = 0; i < matvar->rank; i++ ) {
+        if ( !psnip_safe_size_mul(nelems, *nelems, matvar->dims[i]) ) {
+            *nelems = 0;
+            return 1;
+        }
+    }
+
+    return 0;
+}
+
+/** @brief Multiplies two unsigned integers
+ *
+ * @param res Result
+ * @param a First operand
+ * @param b Second operand
+ * @retval 0 on success
+ */
+int SafeMul(size_t* res, size_t a, size_t b)
+{
+    if ( !psnip_safe_size_mul(res, a, b) ) {
+        *res = 0;
+        return 1;
+    }
+
+    return 0;
+}
+
+/** @brief Adds two unsigned integers
+ *
+ * @param res Result
+ * @param a First operand
+ * @param b Second operand
+ * @retval 0 on success
+ */
+int SafeAdd(size_t* res, size_t a, size_t b)
+{
+    if ( !psnip_safe_size_add(res, a, b) ) {
+        *res = 0;
+        return 1;
+    }
+
+    return 0;
+}
+
 /*
  *===================================================================
  *                 Public Functions
@@ -498,6 +556,22 @@ Mat_GetFilename(mat_t *mat)
     return filename;
 }
 
+/** @brief Gets the header for the given MAT file
+ *
+ * Gets the header for the given MAT file
+ * @ingroup MAT
+ * @param mat Pointer to the MAT file
+ * @return MAT header
+ */
+const char *
+Mat_GetHeader(mat_t *mat)
+{
+    const char *header = NULL;
+    if ( NULL != mat )
+        header = mat->header;
+    return header;
+}
+
 /** @brief Gets the version of the given MAT file
  *
  * Gets the version of the given MAT file
@@ -604,6 +678,15 @@ Mat_GetDir(mat_t *mat, size_t *n)
             (void)fseek((FILE*)mat->fp,fpos,SEEK_SET);
             *n = mat->num_datasets;
         }
+    } else {
+        if ( mat->version == MAT_FT_MAT73 ) {
+            *n = 0;
+            while ( *n < mat->num_datasets && NULL != mat->dir[*n] ) {
+                (*n)++;
+            }
+        } else {
+            *n = mat->num_datasets;
+        }
     }
     dir = mat->dir;
     return dir;
@@ -796,9 +879,9 @@ matvar_t *
 Mat_VarCreate(const char *name,enum matio_classes class_type,
     enum matio_types data_type,int rank,size_t *dims,void *data,int opt)
 {
-    size_t nmemb = 1, data_size;
+    size_t nelems = 1, data_size;
     matvar_t *matvar = NULL;
-    int j;
+    int j, err;
 
     if ( dims == NULL )
         return NULL;
@@ -817,7 +900,7 @@ Mat_VarCreate(const char *name,enum matio_classes class_type,
     matvar->dims = (size_t*)malloc(matvar->rank*sizeof(*matvar->dims));
     for ( j = 0; j < matvar->rank; j++ ) {
         matvar->dims[j] = dims[j];
-        nmemb *= dims[j];
+        nelems *= dims[j];
     }
     matvar->class_type = class_type;
     matvar->data_type  = data_type;
@@ -872,8 +955,8 @@ Mat_VarCreate(const char *name,enum matio_classes class_type,
                 size_t nfields = 0;
                 while ( fields[nfields] != NULL )
                     nfields++;
-                if ( nmemb )
-                    nfields = nfields / nmemb;
+                if ( nelems )
+                    nfields /= nelems;
                 matvar->internal->num_fields = nfields;
                 if ( nfields ) {
                     size_t i;
@@ -881,7 +964,12 @@ Mat_VarCreate(const char *name,enum matio_classes class_type,
                         (char**)calloc(nfields,sizeof(*matvar->internal->fieldnames));
                     for ( i = 0; i < nfields; i++ )
                         matvar->internal->fieldnames[i] = strdup(fields[i]->name);
-                    nmemb *= nfields;
+                    err = SafeMul(&nelems, nelems, nfields);
+                    if ( err ) {
+                        Mat_VarFree(matvar);
+                        Mat_Critical("Integer multiplication overflow");
+                        return NULL;
+                    }
                 }
             }
             break;
@@ -896,11 +984,16 @@ Mat_VarCreate(const char *name,enum matio_classes class_type,
         matvar->nbytes    = matvar->data_size;
     } else {
         matvar->data_size = data_size;
-        matvar->nbytes = nmemb*matvar->data_size;
+        err = SafeMul(&matvar->nbytes, nelems, matvar->data_size);
+        if ( err ) {
+            Mat_VarFree(matvar);
+            Mat_Critical("Integer multiplication overflow");
+            return NULL;
+        }
     }
     if ( data == NULL ) {
-        if ( MAT_C_CELL == matvar->class_type && nmemb > 0 )
-            matvar->data = calloc(nmemb,sizeof(matvar_t*));
+        if ( MAT_C_CELL == matvar->class_type && nelems > 0 )
+            matvar->data = calloc(nelems,sizeof(matvar_t*));
         else
             matvar->data = NULL;
     } else if ( opt & MAT_F_DONT_COPY_DATA ) {
@@ -1288,10 +1381,10 @@ Mat_VarDuplicate(const matvar_t *in, int opt)
     } else if ( (in->data != NULL) && (in->class_type == MAT_C_CELL) ) {
         out->data = malloc(in->nbytes);
         if ( out->data != NULL && in->data_size > 0 ) {
-            size_t ncells = in->nbytes / in->data_size;
+            size_t nelems = in->nbytes / in->data_size;
             matvar_t **incells  = (matvar_t **)in->data;
             matvar_t **outcells = (matvar_t **)out->data;
-            for ( i = 0; i < ncells; i++ ) {
+            for ( i = 0; i < nelems; i++ ) {
                 outcells[i] = Mat_VarDuplicate(incells[i],opt);
             }
         }
@@ -1363,15 +1456,13 @@ Mat_VarDuplicate(const matvar_t *in, int opt)
 void
 Mat_VarFree(matvar_t *matvar)
 {
-    size_t nmemb = 0;
+    size_t nelems = 0;
 
     if ( NULL == matvar )
         return;
     if ( NULL != matvar->dims ) {
-        int j;
-        nmemb = 1;
-        for ( j = 0; j < matvar->rank; j++ )
-            nmemb *= matvar->dims[j];
+        nelems = 1;
+        SafeMulDims(matvar, &nelems);
         free(matvar->dims);
     }
     if ( NULL != matvar->data ) {
@@ -1379,8 +1470,9 @@ Mat_VarFree(matvar_t *matvar)
             case MAT_C_STRUCT:
                 if ( !matvar->mem_conserve ) {
                     matvar_t **fields = (matvar_t**)matvar->data;
-                    size_t nfields = matvar->internal->num_fields, i;
-                    for ( i = 0; i < nmemb*nfields; i++ )
+                    size_t nelems_x_nfields, i;
+                    SafeMul(&nelems_x_nfields, nelems, matvar->internal->num_fields);
+                    for ( i = 0; i < nelems_x_nfields; i++ )
                         Mat_VarFree(fields[i]);
 
                     free(matvar->data);
@@ -1390,7 +1482,7 @@ Mat_VarFree(matvar_t *matvar)
                 if ( !matvar->mem_conserve ) {
                     matvar_t **cells = (matvar_t**)matvar->data;
                     size_t i;
-                    for ( i = 0; i < nmemb; i++ )
+                    for ( i = 0; i < nelems; i++ )
                         Mat_VarFree(cells[i]);
 
                     free(matvar->data);
@@ -1437,9 +1529,13 @@ Mat_VarFree(matvar_t *matvar)
                     }
                 }
                 break;
+            case MAT_C_FUNCTION:
+                if ( !matvar->mem_conserve ) {
+                    free(matvar->data);
+                }
+                break;
             case MAT_C_EMPTY:
             case MAT_C_OBJECT:
-            case MAT_C_FUNCTION:
             case MAT_C_OPAQUE:
                 break;
         }
@@ -1695,11 +1791,12 @@ Mat_CalcSubscripts2(int rank,size_t *dims,size_t index)
  *
  * @ingroup MAT
  * @param matvar matlab variable
- * @returns size of the variable in bytes
+ * @returns size of the variable in bytes, or 0 on error
  */
 size_t
 Mat_VarGetSize(matvar_t *matvar)
 {
+    int err;
     size_t i;
     size_t bytes = 0, overhead = 0, ptr = 0;
 
@@ -1714,65 +1811,96 @@ Mat_VarGetSize(matvar_t *matvar)
 #endif
 
     if ( matvar->class_type == MAT_C_STRUCT ) {
-        int nfields = matvar->internal->num_fields;
-        size_t nmemb = 1;
-        int j;
-        for ( j = 0; j < matvar->rank; j++ )
-            nmemb *= matvar->dims[j];
-        if ( nmemb*nfields > 0 ) {
-            matvar_t **fields = (matvar_t**)matvar->data;
-            if ( NULL != fields ) {
-                bytes = nmemb*nfields*overhead;
-                for ( i = 0; i < nmemb*nfields; i++ ) {
-                    if ( NULL != fields[i] ) {
-                        if ( MAT_C_EMPTY != fields[i]->class_type )
-                            bytes += Mat_VarGetSize(fields[i]);
-                        else
-                            bytes += ptr - overhead;
+        matvar_t **fields = (matvar_t**)matvar->data;
+        size_t field_name_length;
+        if ( NULL != fields ) {
+            size_t nelems_x_nfields = matvar->internal->num_fields;
+            err = SafeMulDims(matvar, &nelems_x_nfields);
+            err |= SafeMul(&bytes, nelems_x_nfields, overhead);
+            if ( err )
+                return 0;
+
+            for ( i = 0; i < nelems_x_nfields; i++ ) {
+                if ( NULL != fields[i] ) {
+                    if ( MAT_C_EMPTY != fields[i]->class_type ) {
+                        err = SafeAdd(&bytes, bytes, Mat_VarGetSize(fields[i]));
+                        if ( err )
+                            return 0;
+                    } else {
+                        bytes -= overhead;
+                        bytes += ptr;
                     }
                 }
             }
         }
-        bytes += 64 /* max field name length */ *nfields;
+        err = SafeMul(&field_name_length, 64 /* max field name length */, matvar->internal->num_fields);
+        err |= SafeAdd(&bytes, bytes, field_name_length);
+        if ( err )
+            return 0;
     } else if ( matvar->class_type == MAT_C_CELL ) {
         matvar_t **cells = (matvar_t**)matvar->data;
         if ( NULL != cells ) {
-            size_t ncells = matvar->nbytes / matvar->data_size;
-            bytes = ncells*overhead;
-            for ( i = 0; i < ncells; i++ ) {
+            size_t nelems = matvar->nbytes / matvar->data_size;
+            err = SafeMul(&bytes, nelems, overhead);
+            if ( err )
+                return 0;
+
+            for ( i = 0; i < nelems; i++ ) {
                 if ( NULL != cells[i] ) {
-                    if ( MAT_C_EMPTY != cells[i]->class_type )
-                        bytes += Mat_VarGetSize(cells[i]);
-                    else
-                        bytes += ptr - overhead;
+                    if ( MAT_C_EMPTY != cells[i]->class_type ) {
+                        err = SafeAdd(&bytes, bytes, Mat_VarGetSize(cells[i]));
+                        if ( err )
+                            return 0;
+                    } else {
+                        bytes -= overhead;
+                        bytes += ptr;
+                    }
                 }
             }
         }
     } else if ( matvar->class_type == MAT_C_SPARSE ) {
         mat_sparse_t *sparse = (mat_sparse_t*)matvar->data;
         if ( NULL != sparse ) {
-            bytes = sparse->ndata*Mat_SizeOf(matvar->data_type);
-            if ( matvar->isComplex )
-                bytes *= 2;
+            size_t sparse_size = 0;
+            err = SafeMul(&bytes, sparse->ndata, Mat_SizeOf(matvar->data_type));
+            if ( err )
+                return 0;
+
+            if ( matvar->isComplex ) {
+                err = SafeMul(&bytes, bytes, 2);
+                if ( err )
+                    return 0;
+            }
+
 #if defined(_WIN64) || (defined(__SIZEOF_POINTER__) && (__SIZEOF_POINTER__ == 8)) || (defined(SIZEOF_VOID_P) && (SIZEOF_VOID_P == 8))
             /* 8 byte integers for 64-bit system (as displayed in MATLAB (x64) whos) */
-            bytes += (sparse->nir + sparse->njc)*8;
+            err = SafeMul(&sparse_size, sparse->nir + sparse->njc, 8);
 #elif defined(_WIN32) || (defined(__SIZEOF_POINTER__) && (__SIZEOF_POINTER__ == 4)) || (defined(SIZEOF_VOID_P) && (SIZEOF_VOID_P == 4))
             /* 4 byte integers for 32-bit system (as defined by mat_sparse_t) */
-            bytes += (sparse->nir + sparse->njc)*4;
+            err = SafeMul(&sparse_size, sparse->nir + sparse->njc, 4);
 #endif
-            if ( sparse->ndata == 0 || sparse->nir == 0 || sparse->njc == 0 )
-                bytes += matvar->isLogical ? 1 : 8;
+            err |= SafeAdd(&bytes, bytes, sparse_size);
+            if ( err )
+                return 0;
+
+            if ( sparse->ndata == 0 || sparse->nir == 0 || sparse->njc == 0 ) {
+                err = SafeAdd(&bytes, bytes, matvar->isLogical ? 1 : 8);
+                if ( err )
+                    return 0;
+            }
         }
     } else {
         if ( matvar->rank > 0 ) {
-            size_t nmemb = 1;
-            int j;
-            for ( j = 0; j < matvar->rank; j++ )
-                nmemb *= matvar->dims[j];
-            bytes = nmemb*Mat_SizeOfClass(matvar->class_type);
-            if ( matvar->isComplex )
-                bytes *= 2;
+            bytes = Mat_SizeOfClass(matvar->class_type);
+            err = SafeMulDims(matvar, &bytes);
+            if ( err )
+                return 0;
+
+            if ( matvar->isComplex ) {
+                err = SafeMul(&bytes, bytes, 2);
+                if (err)
+                    return 0;
+            }
         }
     }
 
@@ -1789,7 +1917,7 @@ Mat_VarGetSize(matvar_t *matvar)
 void
 Mat_VarPrint( matvar_t *matvar, int printdata )
 {
-    size_t nmemb = 0, i, j;
+    size_t nelems = 0, i, j;
     const char *class_type_desc[18] = {"Undefined","Cell Array","Structure",
        "Object","Character Array","Sparse Array","Double Precision Array",
        "Single Precision Array", "8-bit, signed integer array",
@@ -1807,11 +1935,11 @@ Mat_VarPrint( matvar_t *matvar, int printdata )
         return;
     if ( NULL != matvar->dims ) {
         int k;
+        nelems = 1;
+        SafeMulDims(matvar, &nelems);
         printf("Dimensions: %" SIZE_T_FMTSTR,matvar->dims[0]);
-        nmemb = matvar->dims[0];
         for ( k = 1; k < matvar->rank; k++ ) {
             printf(" x %" SIZE_T_FMTSTR,matvar->dims[k]);
-            nmemb *= matvar->dims[k];
         }
         printf("\n");
     }
@@ -1822,7 +1950,7 @@ Mat_VarPrint( matvar_t *matvar, int printdata )
         printf(" (logical)");
     printf("\n");
     if ( matvar->data_type ) {
-        const char *data_type_desc[23] = {"Unknown","8-bit, signed integer",
+        const char *data_type_desc[25] = {"Unknown","8-bit, signed integer",
            "8-bit, unsigned integer","16-bit, signed integer",
            "16-bit, unsigned integer","32-bit, signed integer",
            "32-bit, unsigned integer","IEEE 754 single-precision","RESERVED",
@@ -1830,17 +1958,19 @@ Mat_VarPrint( matvar_t *matvar, int printdata )
            "64-bit, signed integer","64-bit, unsigned integer", "Matlab Array",
            "Compressed Data","Unicode UTF-8 Encoded Character Data",
            "Unicode UTF-16 Encoded Character Data",
-           "Unicode UTF-32 Encoded Character Data","","String","Cell Array",
-           "Structure"};
+           "Unicode UTF-32 Encoded Character Data","RESERVED","String","Cell Array",
+           "Structure","Array","Function"};
         printf(" Data Type: %s\n", data_type_desc[matvar->data_type]);
     }
 
     if ( MAT_C_STRUCT == matvar->class_type ) {
         matvar_t **fields = (matvar_t **)matvar->data;
         size_t nfields = matvar->internal->num_fields;
-        if ( nmemb*nfields > 0 ) {
-            printf("Fields[%" SIZE_T_FMTSTR "] {\n", nfields*nmemb);
-            for ( i = 0; i < nfields*nmemb; i++ ) {
+        size_t nelems_x_nfields = 1;
+        SafeMul(&nelems_x_nfields, nelems, nfields);
+        if ( nelems_x_nfields > 0 ) {
+            printf("Fields[%" SIZE_T_FMTSTR "] {\n", nelems_x_nfields);
+            for ( i = 0; i < nelems_x_nfields; i++ ) {
                 if ( NULL == fields[i] ) {
                     printf("      Name: %s\n      Rank: %d\n",
                            matvar->internal->fieldnames[i%nfields],0);
@@ -1863,9 +1993,9 @@ Mat_VarPrint( matvar_t *matvar, int printdata )
         return;
     } else if ( MAT_C_CELL == matvar->class_type ) {
         matvar_t **cells = (matvar_t **)matvar->data;
-        size_t ncells = matvar->nbytes / matvar->data_size;
+        nelems = matvar->nbytes / matvar->data_size;
         printf("{\n");
-        for ( i = 0; i < ncells; i++ )
+        for ( i = 0; i < nelems; i++ )
             Mat_VarPrint(cells[i],printdata);
         printf("}\n");
         return;
@@ -2061,7 +2191,7 @@ Mat_VarReadData(mat_t *mat,matvar_t *matvar,void *data,
 
     switch ( mat->version ) {
         case MAT_FT_MAT5:
-            err = ReadData5(mat,matvar,data,start,stride,edge);
+            err = Mat_VarReadData5(mat,matvar,data,start,stride,edge);
             break;
         case MAT_FT_MAT73:
 #if defined(MAT73) && MAT73
@@ -2071,7 +2201,7 @@ Mat_VarReadData(mat_t *mat,matvar_t *matvar,void *data,
 #endif
             break;
         case MAT_FT_MAT4:
-            err = ReadData4(mat,matvar,data,start,stride,edge);
+            err = Mat_VarReadData4(mat,matvar,data,start,stride,edge);
             break;
         default:
             err = 2;
@@ -2083,7 +2213,7 @@ Mat_VarReadData(mat_t *mat,matvar_t *matvar,void *data,
 
 /** @brief Reads all the data for a matlab variable
  *
- * Allocates memory for an reads the data for a given matlab variable.
+ * Allocates memory and reads the data for a given matlab variable.
  * @ingroup MAT
  * @param mat Matlab MAT file structure pointer
  * @param matvar Variable whose data is to be read
@@ -2338,21 +2468,17 @@ Mat_VarReadNext( mat_t *mat )
  * @ingroup MAT
  * @param mat MAT file to write to
  * @param matvar MAT variable information to write
- * @retval 0 on success
+ * @retval 1
+ * @deprecated
+ * @see Mat_VarWrite/Mat_VarWriteAppend
  */
 int
 Mat_VarWriteInfo(mat_t *mat, matvar_t *matvar )
 {
-    int err = 0;
-
-    if ( mat == NULL || matvar == NULL || mat->fp == NULL )
-        return -1;
-    else if ( mat->version == MAT_FT_MAT5 )
-        WriteInfo5(mat,matvar);
-    else
-        err = 1;
-
-    return err;
+    Mat_Critical("Mat_VarWriteInfo/Mat_VarWriteData is not supported. "
+        "Use %s instead!", mat->version == MAT_FT_MAT73 ?
+        "Mat_VarWrite/Mat_VarWriteAppend" : "Mat_VarWrite");
+    return 1;
 }
 
 /** @brief Writes the given data to the MAT variable
@@ -2366,68 +2492,18 @@ Mat_VarWriteInfo(mat_t *mat, matvar_t *matvar )
  * @param start array of starting indices
  * @param stride stride of data
  * @param edge array specifying the number to read in each direction
- * @retval 0 on success
+ * @retval 1
+ * @deprecated
+ * @see Mat_VarWrite/Mat_VarWriteAppend
  */
 int
 Mat_VarWriteData(mat_t *mat,matvar_t *matvar,void *data,
       int *start,int *stride,int *edge)
 {
-    int err = 0, k, N = 1;
-
-    if ( mat == NULL || matvar == NULL )
-        return -1;
-
-    if ( NULL != matvar->internal )
-        (void)fseek((FILE*)mat->fp,matvar->internal->datapos+8,SEEK_SET);
-
-    if ( data == NULL ) {
-        err = -1;
-    } else if ( start == NULL && stride == NULL && edge == NULL ) {
-        for ( k = 0; k < matvar->rank; k++ )
-            N *= matvar->dims[k];
-        if ( matvar->compression == MAT_COMPRESSION_NONE )
-            WriteData(mat,data,N,matvar->data_type);
-#if 0
-        else if ( matvar->compression == MAT_COMPRESSION_ZLIB ) {
-            WriteCompressedData(mat,matvar->internal->z,data,N,matvar->data_type);
-            (void)deflateEnd(matvar->internal->z);
-            free(matvar->internal->z);
-            matvar->internal->z = NULL;
-        }
-#endif
-    } else if ( start == NULL || stride == NULL || edge == NULL ) {
-        err = 1;
-    } else if ( matvar->rank == 2 ) {
-        if ( (size_t)stride[0]*(edge[0]-1)+start[0]+1 > matvar->dims[0] ) {
-            err = 1;
-        } else if ( (size_t)stride[1]*(edge[1]-1)+start[1]+1 > matvar->dims[1] ) {
-            err = 1;
-        } else {
-            switch ( matvar->class_type ) {
-                case MAT_C_DOUBLE:
-                case MAT_C_SINGLE:
-                case MAT_C_INT64:
-                case MAT_C_UINT64:
-                case MAT_C_INT32:
-                case MAT_C_UINT32:
-                case MAT_C_INT16:
-                case MAT_C_UINT16:
-                case MAT_C_INT8:
-                case MAT_C_UINT8:
-                    WriteDataSlab2(mat,data,matvar->data_type,matvar->dims,
-                                   start,stride,edge);
-                    break;
-                case MAT_C_CHAR:
-                    WriteCharDataSlab2(mat,data,matvar->data_type,matvar->dims,
-                                   start,stride,edge);
-                    break;
-                default:
-                    break;
-            }
-        }
-    }
-
-    return err;
+    Mat_Critical("Mat_VarWriteInfo/Mat_VarWriteData is not supported. "
+        "Use %s instead!", mat->version == MAT_FT_MAT73 ?
+        "Mat_VarWrite/Mat_VarWriteAppend" : "Mat_VarWrite");
+    return 1;
 }
 
 /** @brief Writes the given MAT variable to a MAT file
