@@ -3,7 +3,7 @@
  * @ingroup MAT
  */
 /*
- * Copyright (c) 2005-2018, Christopher C. Hulbert
+ * Copyright (c) 2005-2019, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -106,7 +106,7 @@ Mat_VarWrite4(mat_t *mat,matvar_t *matvar)
         mat_int32_t namelen;
     } Fmatrix;
 
-    mat_int32_t nmemb = 1, i;
+    mat_int32_t nelems = 1, i;
     Fmatrix x;
 
     if ( NULL == mat || NULL == matvar || NULL == matvar->name || matvar->rank != 2 )
@@ -174,7 +174,7 @@ Mat_VarWrite4(mat_t *mat,matvar_t *matvar)
             for ( i = 0; i < matvar->rank; i++ ) {
                 mat_int32_t dim;
                 dim = (mat_int32_t)matvar->dims[i];
-                nmemb *= dim;
+                nelems *= dim;
             }
 
             x.mrows = (mat_int32_t)matvar->dims[0];
@@ -186,18 +186,18 @@ Mat_VarWrite4(mat_t *mat,matvar_t *matvar)
                 mat_complex_split_t *complex_data;
 
                 complex_data = (mat_complex_split_t*)matvar->data;
-                fwrite(complex_data->Re, matvar->data_size, nmemb, (FILE*)mat->fp);
-                fwrite(complex_data->Im, matvar->data_size, nmemb, (FILE*)mat->fp);
+                fwrite(complex_data->Re, matvar->data_size, nelems, (FILE*)mat->fp);
+                fwrite(complex_data->Im, matvar->data_size, nelems, (FILE*)mat->fp);
             }
             else {
-                fwrite(matvar->data, matvar->data_size, nmemb, (FILE*)mat->fp);
+                fwrite(matvar->data, matvar->data_size, nelems, (FILE*)mat->fp);
             }
             break;
         case MAT_C_SPARSE:
         {
             mat_sparse_t* sparse;
             double tmp;
-            int i, j;
+            int j;
             size_t stride = Mat_SizeOf(matvar->data_type);
 #if !defined(EXTENDED_SPARSE)
             if ( MAT_T_DOUBLE != matvar->data_type )
@@ -220,7 +220,7 @@ Mat_VarWrite4(mat_t *mat,matvar_t *matvar)
                     fwrite(&tmp, sizeof(double), 1, (FILE*)mat->fp);
                 }
             }
-            tmp = matvar->dims[0];
+            tmp = (double)matvar->dims[0];
             fwrite(&tmp, sizeof(double), 1, (FILE*)mat->fp);
             for ( i = 0; i < sparse->njc - 1; i++ ) {
                 for ( j = sparse->jc[i];
@@ -229,7 +229,7 @@ Mat_VarWrite4(mat_t *mat,matvar_t *matvar)
                     fwrite(&tmp, sizeof(double), 1, (FILE*)mat->fp);
                 }
             }
-            tmp = matvar->dims[1];
+            tmp = (double)matvar->dims[1];
             fwrite(&tmp, sizeof(double), 1, (FILE*)mat->fp);
             tmp = 0.;
             if ( matvar->isComplex ) {
@@ -280,23 +280,34 @@ Mat_VarWrite4(mat_t *mat,matvar_t *matvar)
  * @endif
  */
 void
-Read4(mat_t *mat,matvar_t *matvar)
+Mat_VarRead4(mat_t *mat,matvar_t *matvar)
 {
-    size_t N;
+    int err;
+    size_t nelems = 1;
+
+    err = SafeMulDims(matvar, &nelems);
+    if ( err ) {
+        Mat_Critical("Integer multiplication overflow");
+        return;
+    }
 
     (void)fseek((FILE*)mat->fp,matvar->internal->datapos,SEEK_SET);
 
-    N = matvar->dims[0]*matvar->dims[1];
     switch ( matvar->class_type ) {
         case MAT_C_DOUBLE:
             matvar->data_size = sizeof(double);
-            matvar->nbytes    = N*matvar->data_size;
+            err = SafeMul(&matvar->nbytes, nelems, matvar->data_size);
+            if ( err ) {
+                Mat_Critical("Integer multiplication overflow");
+                return;
+            }
+
             if ( matvar->isComplex ) {
                 mat_complex_split_t *complex_data = ComplexMalloc(matvar->nbytes);
                 if ( NULL != complex_data ) {
                     matvar->data = complex_data;
-                    ReadDoubleData(mat, (double*)complex_data->Re, matvar->data_type, N);
-                    ReadDoubleData(mat, (double*)complex_data->Im, matvar->data_type, N);
+                    ReadDoubleData(mat, (double*)complex_data->Re, matvar->data_type, nelems);
+                    ReadDoubleData(mat, (double*)complex_data->Im, matvar->data_type, nelems);
                 }
                 else {
                     Mat_Critical("Couldn't allocate memory for the complex data");
@@ -304,7 +315,7 @@ Read4(mat_t *mat,matvar_t *matvar)
             } else {
                 matvar->data = malloc(matvar->nbytes);
                 if ( NULL != matvar->data ) {
-                    ReadDoubleData(mat, (double*)matvar->data, matvar->data_type, N);
+                    ReadDoubleData(mat, (double*)matvar->data, matvar->data_type, nelems);
                 }
                 else {
                     Mat_Critical("Couldn't allocate memory for the data");
@@ -315,10 +326,10 @@ Read4(mat_t *mat,matvar_t *matvar)
             break;
         case MAT_C_CHAR:
             matvar->data_size = 1;
-            matvar->nbytes = N;
+            matvar->nbytes = nelems;
             matvar->data = malloc(matvar->nbytes);
             if ( NULL != matvar->data ) {
-                ReadUInt8Data(mat,(mat_uint8_t*)matvar->data,matvar->data_type,N);
+                ReadUInt8Data(mat, (mat_uint8_t*)matvar->data, matvar->data_type, nelems);
             }
             else {
                 Mat_Critical("Couldn't allocate memory for the data");
@@ -494,7 +505,7 @@ Read4(mat_t *mat,matvar_t *matvar)
                                 free(sparse->ir);
                                 free(matvar->data);
                                 matvar->data = NULL;
-                                Mat_Critical("Read4: %d is not a supported data type for "
+                                Mat_Critical("Mat_VarRead4: %d is not a supported data type for "
                                     "extended sparse", data_type);
                                 return;
                         }
@@ -571,7 +582,7 @@ Read4(mat_t *mat,matvar_t *matvar)
                                 free(sparse->ir);
                                 free(matvar->data);
                                 matvar->data = NULL;
-                                Mat_Critical("Read4: %d is not a supported data type for "
+                                Mat_Critical("Mat_VarRead4: %d is not a supported data type for "
                                     "extended sparse", data_type);
                                 return;
                         }
@@ -617,7 +628,7 @@ Read4(mat_t *mat,matvar_t *matvar)
  * @endif
  */
 int
-ReadData4(mat_t *mat,matvar_t *matvar,void *data,
+Mat_VarReadData4(mat_t *mat,matvar_t *matvar,void *data,
       int *start,int *stride,int *edge)
 {
     int err = 0;
@@ -643,7 +654,12 @@ ReadData4(mat_t *mat,matvar_t *matvar,void *data,
             err = 1;
         if ( matvar->isComplex ) {
             mat_complex_split_t *cdata = (mat_complex_split_t*)data;
-            long nbytes = matvar->dims[0]*matvar->dims[1]*Mat_SizeOf(matvar->data_type);
+            size_t nbytes = Mat_SizeOf(matvar->data_type);
+            err = SafeMulDims(matvar, &nbytes);
+            if ( err ) {
+                Mat_Critical("Integer multiplication overflow");
+                return err;
+            }
 
             ReadDataSlab2(mat,cdata->Re,matvar->class_type,matvar->data_type,
                 matvar->dims,start,stride,edge);
@@ -655,12 +671,13 @@ ReadData4(mat_t *mat,matvar_t *matvar,void *data,
                 matvar->dims,start,stride,edge);
         }
     } else if ( matvar->isComplex ) {
-        int i;
         mat_complex_split_t *cdata = (mat_complex_split_t*)data;
-        long nbytes = Mat_SizeOf(matvar->data_type);
-
-        for ( i = 0; i < matvar->rank; i++ )
-            nbytes *= matvar->dims[i];
+        size_t nbytes = Mat_SizeOf(matvar->data_type);
+        err = SafeMulDims(matvar, &nbytes);
+        if ( err ) {
+            Mat_Critical("Integer multiplication overflow");
+            return err;
+        }
 
         ReadDataSlabN(mat,cdata->Re,matvar->class_type,matvar->data_type,
             matvar->rank,matvar->dims,start,stride,edge);
@@ -692,28 +709,35 @@ int
 Mat_VarReadDataLinear4(mat_t *mat,matvar_t *matvar,void *data,int start,
                        int stride,int edge)
 {
-    size_t nmemb = 1;
-    int err = 0, i;
+    int err;
+    size_t nelems = 1;
+
+    err = SafeMulDims(matvar, &nelems);
+    if ( err ) {
+        Mat_Critical("Integer multiplication overflow");
+        return err;
+    }
 
     (void)fseek((FILE*)mat->fp,matvar->internal->datapos,SEEK_SET);
 
     matvar->data_size = Mat_SizeOf(matvar->data_type);
 
-    for ( i = 0; i < matvar->rank; i++ )
-        nmemb *= matvar->dims[i];
-
-    if ( (size_t)stride*(edge-1)+start+1 > nmemb ) {
+    if ( (size_t)stride*(edge-1)+start+1 > nelems ) {
         return 1;
     }
     if ( matvar->isComplex ) {
-            mat_complex_split_t *complex_data = (mat_complex_split_t*)data;
-            long nbytes = nmemb*matvar->data_size;
+        mat_complex_split_t *complex_data = (mat_complex_split_t*)data;
+        err = SafeMul(&nelems, nelems, matvar->data_size);
+        if ( err ) {
+            Mat_Critical("Integer multiplication overflow");
+            return err;
+        }
 
-            ReadDataSlab1(mat,complex_data->Re,matvar->class_type,
-                          matvar->data_type,start,stride,edge);
-            (void)fseek((FILE*)mat->fp,matvar->internal->datapos+nbytes,SEEK_SET);
-            ReadDataSlab1(mat,complex_data->Im,matvar->class_type,
-                          matvar->data_type,start,stride,edge);
+        ReadDataSlab1(mat,complex_data->Re,matvar->class_type,
+                      matvar->data_type,start,stride,edge);
+        (void)fseek((FILE*)mat->fp,matvar->internal->datapos+nelems,SEEK_SET);
+        ReadDataSlab1(mat,complex_data->Im,matvar->class_type,
+                      matvar->data_type,start,stride,edge);
     } else {
         ReadDataSlab1(mat,data,matvar->class_type,matvar->data_type,start,
                       stride,edge);
@@ -736,7 +760,7 @@ Mat_VarReadNextInfo4(mat_t *mat)
     int       M,O,data_type,class_type;
     mat_int32_t tmp;
     long      nBytes;
-    size_t    err;
+    size_t    readresult;
     matvar_t *matvar = NULL;
     union {
         mat_uint32_t u;
@@ -748,8 +772,8 @@ Mat_VarReadNextInfo4(mat_t *mat)
     else if ( NULL == (matvar = Mat_VarCalloc()) )
         return NULL;
 
-    err = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
-    if ( !err ) {
+    readresult = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
+    if ( 1 != readresult ) {
         Mat_VarFree(matvar);
         return NULL;
     }
@@ -835,25 +859,25 @@ Mat_VarReadNextInfo4(mat_t *mat)
         Mat_VarFree(matvar);
         return NULL;
     }
-    err = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
+    readresult = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
     if ( mat->byteswap )
         Mat_int32Swap(&tmp);
     matvar->dims[0] = tmp;
-    if ( !err ) {
+    if ( 1 != readresult ) {
         Mat_VarFree(matvar);
         return NULL;
     }
-    err = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
+    readresult = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
     if ( mat->byteswap )
         Mat_int32Swap(&tmp);
     matvar->dims[1] = tmp;
-    if ( !err ) {
+    if ( 1 != readresult ) {
         Mat_VarFree(matvar);
         return NULL;
     }
 
-    err = fread(&(matvar->isComplex),sizeof(int),1,(FILE*)mat->fp);
-    if ( !err ) {
+    readresult = fread(&(matvar->isComplex),sizeof(int),1,(FILE*)mat->fp);
+    if ( 1 != readresult ) {
         Mat_VarFree(matvar);
         return NULL;
     }
@@ -861,8 +885,8 @@ Mat_VarReadNextInfo4(mat_t *mat)
         Mat_VarFree(matvar);
         return NULL;
     }
-    err = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
-    if ( !err ) {
+    readresult = fread(&tmp,sizeof(int),1,(FILE*)mat->fp);
+    if ( 1 != readresult ) {
         Mat_VarFree(matvar);
         return NULL;
     }
@@ -878,8 +902,8 @@ Mat_VarReadNextInfo4(mat_t *mat)
         Mat_VarFree(matvar);
         return NULL;
     }
-    err = fread(matvar->name,1,tmp,(FILE*)mat->fp);
-    if ( !err ) {
+    readresult = fread(matvar->name,1,tmp,(FILE*)mat->fp);
+    if ( tmp != readresult ) {
         Mat_VarFree(matvar);
         return NULL;
     }
@@ -890,9 +914,20 @@ Mat_VarReadNextInfo4(mat_t *mat)
         Mat_Critical("Couldn't determine file position");
         return NULL;
     }
-    nBytes = matvar->dims[0]*matvar->dims[1]*Mat_SizeOf(matvar->data_type);
-    if ( matvar->isComplex )
-        nBytes *= 2;
+    {
+        int err;
+        size_t tmp2 = Mat_SizeOf(matvar->data_type);
+        if ( matvar->isComplex )
+            tmp2 *= 2;
+        err = SafeMulDims(matvar, &tmp2);
+        if ( err ) {
+            Mat_VarFree(matvar);
+            Mat_Critical("Integer multiplication overflow");
+            return NULL;
+        }
+
+        nBytes = (long)tmp2;
+    }
     (void)fseek((FILE*)mat->fp,nBytes,SEEK_CUR);
 
     return matvar;
