@@ -211,15 +211,10 @@ EXTERN size_t InflateSkipData(mat_t *mat,z_streamp z,enum matio_types data_type,
 EXTERN size_t InflateVarTag(mat_t *mat, matvar_t *matvar, void *buf);
 EXTERN size_t InflateArrayFlags(mat_t *mat, matvar_t *matvar, void *buf);
 EXTERN size_t InflateRankDims(mat_t *mat, matvar_t *matvar, void *buf, size_t nbytes, mat_uint32_t** dims);
-EXTERN size_t InflateVarNameTag(mat_t *mat, matvar_t *matvar, void *buf);
 EXTERN size_t InflateVarName(mat_t *mat,matvar_t *matvar,void *buf,int N);
 EXTERN size_t InflateDataTag(mat_t *mat, matvar_t *matvar, void *buf);
 EXTERN size_t InflateDataType(mat_t *mat, z_stream *z, void *buf);
 EXTERN size_t InflateData(mat_t *mat, z_streamp z, void *buf, unsigned int nBytes);
-EXTERN size_t InflateFieldNameLength(mat_t *mat,matvar_t *matvar,void *buf);
-EXTERN size_t InflateFieldNamesTag(mat_t *mat,matvar_t *matvar,void *buf);
-EXTERN size_t InflateFieldNames(mat_t *mat,matvar_t *matvar,void *buf,int nfields,
-               int fieldname_length,int padding);
 #endif
 
 /* mat.c */
