@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2018, Christopher C. Hulbert
+ * Copyright (c) 2005-2019, Christopher C. Hulbert
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -759,7 +759,6 @@ print_default(matvar_t *matvar)
             break;
         case MAT_C_STRUCT:
         {
-            matvar_t **fields = (matvar_t **)matvar->data;
             int        nfields;
             int        i;
             size_t     nmemb;
@@ -778,15 +777,21 @@ print_default(matvar_t *matvar)
                 char * const *fieldnames = Mat_VarGetStructFieldnames(matvar);
                 Mat_Message("Fields[%d] {", nfields);
                 indent++;
-                for ( i = 0; i < nfields; i++ )
-                    Mat_Message("    Name: %s", fieldnames[i]);
+                if ( NULL != fieldnames ) {
+                    for ( i = 0; i < nfields; i++ )
+                        Mat_Message("    Name: %s", fieldnames[i]);
+                }
                 indent--;
                 Mat_Message("}");
             } else if ( nfields > 0 && nmemb > 0 ) {
                 Mat_Message("Fields[%d] {", nfields);
                 indent++;
-                for ( i = 0; i < nfields*nmemb; i++ )
-                    print_default(fields[i]);
+                {
+                    matvar_t **fields = (matvar_t **)matvar->data;
+                    if ( NULL != fields )
+                        for ( i = 0; i < nfields*nmemb; i++ )
+                            print_default(fields[i]);
+                }
                 indent--;
                 Mat_Message("}");
             }
@@ -794,7 +799,6 @@ print_default(matvar_t *matvar)
         }
         case MAT_C_CELL:
         {
-            matvar_t **cells = (matvar_t **)matvar->data;
             size_t     ncells;
             int        i;
 
@@ -809,8 +813,12 @@ print_default(matvar_t *matvar)
             Mat_Message("Class Type: Cell Array");
             Mat_Message("{");
             indent++;
-            for ( i = 0; i < ncells; i++ )
-                print_default(cells[i]);
+            {
+                matvar_t **cells = (matvar_t **)matvar->data;
+                if ( NULL != cells )
+                    for ( i = 0; i < ncells; i++ )
+                        print_default(cells[i]);
+            }
             indent--;
             Mat_Message("}");
             break;
@@ -872,7 +880,7 @@ main (int argc, char *argv[])
                 exit(EXIT_SUCCESS);
             case 'V':
                 printf("%s %s\nWritten by Christopher Hulbert\n\n"
-                       "Copyright(C) 2006-2018 Christopher C. Hulbert\n",
+                       "Copyright(C) 2006-2019, Christopher C. Hulbert\n",
                        prog_name,MATIO_VERSION_STR);
                 exit(EXIT_SUCCESS);
             default:
